==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'pou nouvo atik yo ke rive apré sélman (okenn aksyon sou bazdone).',
	'bouton_radio_articles_tous' => 'pou tout atik yo mèm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pout tout atik yo, sof kank yon fowom a y pa mache.',
	'bouton_radio_enregistrement_obligatoire' => 'Enskrisyon nesesè (
 fòk itilizatè yo abonn a w ek donn yon ladrès limèl avan poste yon patisipasyon)
.',
	'bouton_radio_moderation_priori' => 'Modèwasyon avan (
patisipasyon yo zitilizatè tout ke pa afiche sou sitwèb piblik si yon komandé te pa konfime y
).', # MODIF
	'bouton_radio_modere_abonnement' => 'Fòk yon abònman',
	'bouton_radio_modere_posteriori' => 'Modewe dèyè', # MODIF
	'bouton_radio_modere_priori' => 'modewe avan', # MODIF
	'bouton_radio_publication_immediate' => 'Piblikasyon imedyat pout tout mesaj
 (patisipasyon ke afiche dirèkman yo te voye, komandè rès kapab kraze y aprè
).',

	// F
	'form_pet_message_commentaire' => 'Gen yon mesaj, yon komanté pou di ?',
	'forum' => 'Fowom',
	'forum_acces_refuse' => 'W ap pli laksé pou fowom-nan.',
	'forum_attention_dix_caracteres' => '<b>Atansyon !</b> mesaj ou li se mwen di lèt.',
	'forum_attention_trois_caracteres' => '<b>Atansyon !</b> Kouman i rele sit-la se mwen trwa lèt. Fôk w mèt trwa lèt omwen',
	'forum_attention_trop_caracteres' => '<b>Atansyon !</b> mesaje a w se tro lon (@compte@ caractères) : fòk w respek @max@ karaktèr pou enskri ali.', # MODIF
	'forum_avez_selectionne' => 'W te chwazi :',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>isit</a> pou kontinye.',
	'forum_forum' => 'fowom',
	'forum_info_modere' => 'Fowom la se modéwé-avann : patisipasyon demoun ke aparèt sèlman apré yon komandèr  sit te valide ali.', # MODIF
	'forum_lien_hyper' => '<b>Lyen ipèrtèks</b> (w pa oblijé)', # MODIF
	'forum_message_definitif' => 'Mesaj fin fini : anvway anndan sit la',
	'forum_message_trop_long' => 'Mesaj ou se tro lon. Pli gran tay se 20000 kawaktè.', # MODIF
	'forum_ne_repondez_pas' => 'Reponn pa limèl la. Reponn anndan fowom-an sou ladrès la :', # MODIF
	'forum_page_url' => '(Si mesaj ou ka voye sou yon tik sou Wèb déò ou yon lòt paj pli konplé, mèsi mèt anba kouman paj la  ka rele èk ladrès URL.)',
	'forum_poste_par' => 'Mesaj te poste @parauteur@ anba atik ou-a.', # MODIF
	'forum_qui_etes_vous' => '<b>Kouman w rele ?</b> (pa oblijé)', # MODIF
	'forum_texte' => 'Teks mesaj ou :', # MODIF
	'forum_titre' => 'Kouman i rele mesaj ou :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Apiyé chwa-a',
	'forum_voir_avant' => 'Gad mesaj la avan post ali', # MODIF
	'forum_votre_email' => 'Ladrès limèl ou :', # MODIF
	'forum_votre_nom' => 'Kouman w rele (ousinon kouman w vlé rele isit) :', # MODIF
	'forum_vous_enregistrer' => 'Pou soutni andan
 fowom-nan, fòk w enskri avan. Mési
 mèt enba lidantifyan pèsonèl ou-a 
 kis nou té don a w. Si w ap pa enskri ankò, fòk w',
	'forum_vous_inscrire' => 'enskri w.',

	// I
	'icone_poster_message' => 'Poste yon mesaj',
	'icone_suivi_forum' => 'Swiv fowom piblik la : @nb_forums@ mesaj',
	'icone_suivi_forums' => 'Swiv/okipe tout fowom ',
	'icone_supprimer_message' => 'Kraze mesaj la',
	'icone_valider_message' => 'Konfime mesaj la',
	'info_activer_forum_public' => '<i>Pou fowom piblik mache, mési chwazi manyir modèr a y otomatikman
:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Fè mache chwa nan pou modéwasyon :',
	'info_desactiver_forum_public' => 'Pou fé fowom piblik pa mache. Fowom yo ke mache yon pa yon si w vlé
anba atik yo ; y ke entèdi pou tout ribrik yo, é tinouvèl yo...',
	'info_envoi_forum' => 'Voye fowom yo pou tout loté atik yo',
	'info_fonctionnement_forum' => 'Kouman fowom i mache :',
	'info_gauche_suivi_forum_2' => 'Paj <i>swivi fowom yo</i> se outiy pou sit w (kontrè yon espas pou soutni ek ekri ant zot itlizatè. Li afich tout patispasyon nan fowom sou sit piblik tankou espas privé ak li ran aw kapab okipe yo.', # MODIF
	'info_liens_syndiques_3' => 'fowom yo',
	'info_liens_syndiques_4' => 'se',
	'info_liens_syndiques_5' => 'fowom',
	'info_liens_syndiques_6' => 'se',
	'info_liens_syndiques_7' => 'fowom ki tann konfime',
	'info_mode_fonctionnement_defaut_forum_public' => 'Kouman tout fowom piblik mache otomatikman',
	'info_option_email' => 'Kan yon vizitè ap voye yon nouvo mesaj nan fowom sou yon atik
se posib alèt tout lotè atik la
ak yon limèl. W vle itilize opsyon nan ?', # MODIF
	'info_pas_de_forum' => 'Okenn fowom',
	'item_activer_forum_administrateur' => 'Fé mache fowom pou komandé yo ',
	'item_desactiver_forum_administrateur' => 'Rete fowom pou komandé yo',

	// L
	'lien_reponse_article' => 'Réponn atik-la',
	'lien_reponse_breve_2' => 'Réponn tinouvèl-la',
	'lien_reponse_rubrique' => 'Réponn ribrik-la',
	'lien_reponse_site_reference' => 'Reponn sit referanse-a :', # MODIF

	// O
	'onglet_messages_internes' => 'Mesaj yo ki andan sit-la',
	'onglet_messages_publics' => 'Mesaj piblik yo',
	'onglet_messages_vide' => 'Mesaj yo ki gen pa oken tèks',

	// R
	'repondre_message' => 'Reponn sou mesaj la',

	// T
	'titre_cadre_forum_administrateur' => 'Fowom privé pou komandè yo',
	'titre_cadre_forum_interne' => 'Fowom andedan',
	'titre_forum' => 'Fowom',
	'titre_forum_suivi' => 'Swivi fowom yo',
	'titre_page_forum_suivi' => 'Pou swiv tout fowom yo',
];

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'pou nouvo atik yo ke rive apré sélman (okenn aksyon sou bazdone).',
	'bouton_radio_articles_tous' => 'pou tout atik yo mèm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pout tout atik yo, sof kank yon fowom a y pa mache.',
	'bouton_radio_enregistrement_obligatoire' => 'Enskrisyon nesesè (
 fòk itilizatè yo abonn a w ek donn yon ladrès limèl avan poste yon patisipasyon)
.', # MODIF
	'bouton_radio_moderation_priori' => 'Modèwasyon avan (
patisipasyon yo zitilizatè tout ke pa afiche sou sitwèb piblik si yon komandé te pa konfime y
).', # MODIF
	'bouton_radio_modere_abonnement' => 'Fòk yon abònman',
	'bouton_radio_modere_posteriori' => 'Modewe dèyè', # MODIF
	'bouton_radio_modere_priori' => 'modewe avan', # MODIF
	'bouton_radio_publication_immediate' => 'Piblikasyon imedyat pout tout mesaj
 (patisipasyon ke afiche dirèkman yo te voye, komandè rès kapab kraze y aprè
).', # MODIF

	// F
	'form_pet_message_commentaire' => 'Gen yon mesaj, yon komanté pou di ?',
	'forum' => 'Fowom',
	'forum_acces_refuse' => 'W ap pli laksé pou fowom-nan.',
	'forum_attention_dix_caracteres' => '<b>Atansyon !</b> mesaj ou li se mwen di lèt.',
	'forum_attention_trois_caracteres' => '<b>Atansyon !</b> Kouman i rele sit-la se mwen trwa lèt. Fôk w mèt trwa lèt omwen',
	'forum_attention_trop_caracteres' => '<b>Atansyon !</b> mesaje a w se tro lon (@compte@ caractères) : fòk w respek @max@ karaktèr pou enskri ali.', # MODIF
	'forum_avez_selectionne' => 'W te chwazi :',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>isit</a> pou kontinye.',
	'forum_forum' => 'fowom',
	'forum_info_modere' => 'Fowom la se modéwé-avann : patisipasyon demoun ke aparèt sèlman apré yon komandèr  sit te valide ali.', # MODIF
	'forum_lien_hyper' => '<b>Lyen ipèrtèks</b> (w pa oblijé)', # MODIF
	'forum_message_definitif' => 'Mesaj fin fini : anvway anndan sit la',
	'forum_message_trop_long' => 'Mesaj ou se tro lon. Pli gran tay se 20000 kawaktè.', # MODIF
	'forum_ne_repondez_pas' => 'Reponn pa limèl la. Reponn anndan fowom-an sou ladrès la :', # MODIF
	'forum_page_url' => '(Si mesaj ou ka voye sou yon tik sou Wèb déò ou yon lòt paj pli konplé, mèsi mèt anba kouman paj la  ka rele èk ladrès URL.)',
	'forum_poste_par' => 'Mesaj te poste @parauteur@ anba atik ou-a.', # MODIF
	'forum_qui_etes_vous' => '<b>Kouman w rele ?</b> (pa oblijé)', # MODIF
	'forum_texte' => 'Teks mesaj ou :', # MODIF
	'forum_titre' => 'Kouman i rele mesaj ou :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Apiyé chwa-a',
	'forum_voir_avant' => 'Gad mesaj la avan post ali', # MODIF
	'forum_votre_email' => 'Ladrès limèl ou :', # MODIF
	'forum_votre_nom' => 'Kouman w rele (ousinon kouman w vlé rele isit) :', # MODIF
	'forum_vous_enregistrer' => 'Pou soutni andan
 fowom-nan, fòk w enskri avan. Mési
 mèt enba lidantifyan pèsonèl ou-a 
 kis nou té don a w. Si w ap pa enskri ankò, fòk w',
	'forum_vous_inscrire' => 'enskri w.',

	// I
	'icone_poster_message' => 'Poste yon mesaj',
	'icone_suivi_forum' => 'Swiv fowom piblik la : @nb_forums@ mesaj',
	'icone_suivi_forums' => 'Swiv/okipe tout fowom ',
	'icone_supprimer_message' => 'Kraze mesaj la',
	'icone_valider_message' => 'Konfime mesaj la',
	'info_activer_forum_public' => '<i>Pou fowom piblik mache, mési chwazi manyir modèr a y otomatikman
:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Fè mache chwa nan pou modéwasyon :',
	'info_desactiver_forum_public' => 'Pou fé fowom piblik pa mache. Fowom yo ke mache yon pa yon si w vlé
anba atik yo ; y ke entèdi pou tout ribrik yo, é tinouvèl yo...',
	'info_envoi_forum' => 'Voye fowom yo pou tout loté atik yo', # MODIF
	'info_fonctionnement_forum' => 'Kouman fowom i mache :',
	'info_gauche_suivi_forum_2' => 'Paj <i>swivi fowom yo</i> se outiy pou sit w (kontrè yon espas pou soutni ek ekri ant zot itlizatè. Li afich tout patispasyon nan fowom sou sit piblik tankou espas privé ak li ran aw kapab okipe yo.', # MODIF
	'info_liens_syndiques_3' => 'fowom yo',
	'info_liens_syndiques_4' => 'se',
	'info_liens_syndiques_5' => 'fowom',
	'info_liens_syndiques_6' => 'se',
	'info_liens_syndiques_7' => 'fowom ki tann konfime',
	'info_mode_fonctionnement_defaut_forum_public' => 'Kouman tout fowom piblik mache otomatikman',
	'info_option_email' => 'Kan yon vizitè ap voye yon nouvo mesaj nan fowom sou yon atik
se posib alèt tout lotè atik la
ak yon limèl. W vle itilize opsyon nan ?', # MODIF
	'info_pas_de_forum' => 'Okenn fowom',
	'item_activer_forum_administrateur' => 'Fé mache fowom pou komandé yo ', # MODIF
	'item_desactiver_forum_administrateur' => 'Rete fowom pou komandé yo', # MODIF

	// L
	'lien_reponse_article' => 'Réponn atik-la',
	'lien_reponse_breve_2' => 'Réponn tinouvèl-la',
	'lien_reponse_rubrique' => 'Réponn ribrik-la',
	'lien_reponse_site_reference' => 'Reponn sit referanse-a :', # MODIF

	// O
	'onglet_messages_internes' => 'Mesaj yo ki andan sit-la',
	'onglet_messages_publics' => 'Mesaj piblik yo',
	'onglet_messages_vide' => 'Mesaj yo ki gen pa oken tèks',

	// R
	'repondre_message' => 'Reponn sou mesaj la',

	// T
	'titre_cadre_forum_administrateur' => 'Fowom privé pou komandè yo', # MODIF
	'titre_cadre_forum_interne' => 'Fowom andedan',
	'titre_forum' => 'Fowom',
	'titre_forum_suivi' => 'Swivi fowom yo',
	'titre_page_forum_suivi' => 'Pou swiv tout fowom yo',
];
